@@ -1,6 +1,6 @@
 package Kevin::Plugin::kevin;
-$Kevin::Plugin::kevin::VERSION = '0.3.0';
-# ABSTRACT: Mojolicious plugin for alternative minion commands
+$Kevin::Plugin::kevin::VERSION = '0.4.0';
+# ABSTRACT: DEPRECATED! Mojolicious plugin for alternative minion commands
 use Mojo::Base 'Mojolicious::Plugin::Kevin::Commands';
 
 1;
@@ -25,11 +25,11 @@ __END__
 
 =head1 NAME
 
-Kevin::Plugin::kevin - Mojolicious plugin for alternative minion commands
+Kevin::Plugin::kevin - DEPRECATED! Mojolicious plugin for alternative minion commands
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 DESCRIPTION
 
