@@ -1,13 +1,13 @@
 
 package Mojolicious::Plugin::Kevin::Commands;
-$Mojolicious::Plugin::Kevin::Commands::VERSION = '0.3.0';
+$Mojolicious::Plugin::Kevin::Commands::VERSION = '0.4.0';
 # ABSTRACT: Mojolicious plugin for alternative minion commands
 use Mojo::Base 'Mojolicious::Plugin';
 
 sub register {
   my ($self, $app, $conf) = @_;
 
-  unshift @{$app->commands->namespaces}, 'Kevin::Command';
+  push @{$app->commands->namespaces}, 'Kevin::Command';
 }
 
 1;
@@ -64,7 +64,7 @@ Mojolicious::Plugin::Kevin::Commands - Mojolicious plugin for alternative minion
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
